@@ -9,12 +9,12 @@ require Exporter;
 
 our @ISA = ("Exporter");
 
-our $VERSION = "0.12";
+our $VERSION = "1.02";
 
 our @EXPORT = qw(sapply mapply happly tapply initial_array initial_matrix order
                  rank sort_array reverse_array repeat rep copy paste seq c test 
-                 unique subset subset_value which dim t matrix_prod is_array_identical 
-                 is_matrix_identical outer match len abs plus minus multiply divide
+                 unique subset subset_value which all any dim t matrix_prod is_array_identical 
+                 is_matrix_identical outer inner match len abs plus minus multiply divide
                  print_ref print_matrix read_table write_table intersect union
                  setdiff setequal is_element sign sum mean geometric_mean 
                  sd var cov cor dist freq table scale sample del_array_item 
@@ -25,15 +25,15 @@ our @EXPORT = qw(sapply mapply happly tapply initial_array initial_matrix order
 our %EXPORT_TAGS = (
      apply => [qw(sapply mapply happly tapply)],
      list  => [qw(initial_array initial_matrix order rank sort_array reverse_array
-		          repeat rep copy paste seq c test unique subset subset_value
-			      which dim t matrix_prod is_array_identical is_matrix_identical
-			      outer match len is_empty del_array_item plus minus multiply divide)],
+                  repeat rep copy paste seq c test unique subset subset_value
+                  which all any dim t matrix_prod is_array_identical is_matrix_identical
+                  outer inner match len is_empty del_array_item plus minus multiply divide)],
      io    => [qw(print_ref print_matrix read_table write_table)],
      set   => [qw(intersect union setdiff setequal is_element)],
      stat  => [qw(sign sum mean geometric_mean sd var cov cor dist freq table scale
-			      sample rnorm rbinom max min which_max which_min
-			      median quantile iqr cumf abs)]
-);			  
+                  sample rnorm rbinom max min which_max which_min
+                  median quantile iqr cumf abs)]
+);              
 
 my $module = __PACKAGE__;
 $module =~s/::/\//g;
@@ -41,12 +41,51 @@ $module =~s/::/\//g;
 # find the module library directory
 my $module_dir = ".";
 foreach (@INC) {
-	if( -e "$_/$module.pm") {
-		$module_dir = $_;
-		last;
-	}
+    if( -e "$_/$module.pm") {
+        $module_dir = $_;
+        last;
+    }
 }
 
+our $REF_TYPE = {'SCALAR' => '$',
+                 'ARRAY' => '@',
+                 'HASH' => '%',
+                 'CODE' => '&',
+                 'GLOB' => '*',
+                 'Regexp' => 'm',
+                 'REF' => '$',
+                 };
+                 
+# variable in @_ are all references
+sub check_prototype {
+    my $prototype = pop;
+    my $prototype_as_string = $prototype;
+    if(ref($prototype) ne "Regexp") {
+        $prototype =~s/\\/\\\\/g;
+        $prototype =~s/([\$\&\%\@\*])/\\$1/g;
+        $prototype = qr/$prototype/;
+    }
+    
+    my $p = '';
+    for(my $i = 0; $i < scalar(@_); $i ++) {
+        if(ref($_[$i])) {
+            $p .= '\\'.$REF_TYPE->{ref($_[$i])};
+        }
+        else {
+            $p .= $REF_TYPE->{ref(\$_[$i])};
+        }
+    }
+    
+    if($p=~/^$prototype$/) {
+        return 1;
+    }
+    else {
+        confess "ERROR: your prototype is '$p', but it should be '$prototype_as_string' ($prototype).\n";
+    }
+}
+
+
+
 # get all functions
 require("$module_dir/$module/lib/Apply.pl");
 require("$module_dir/$module/lib/List.pl");
@@ -65,46 +104,56 @@ __END__
 
 =head1 NAME
 
-List::Vectorize - functions in R style.
+List::Vectorize - functions to make vectorized calculation easy.
 
 =head1 SYNOPSIS
 
   use List::Vectorize;               # export all functions
   use List::Vectorize qw(:apply);    # export apply family functions
-  use List::Vectorize qw(:list);     # export functions manuplate list
-  use List::Vectorize qw(:set);      # export functions manuplate sets
-  use List::Vectorize qw(:stat);     # export functions to do statistical things
-  use List::Vectorize qw(:io);       # export functions to print or read data
+  use List::Vectorize qw(:list);     # export functions that manuplate lists/vectors
+  use List::Vectorize qw(:set);      # export functions that manuplate sets
+  use List::Vectorize qw(:stat);     # export functions that do statistical things
+  use List::Vectorize qw(:io);       # export functions that print or read data
 
 =head1 DESCRIPTION
 
-The module implement some functions in C<R> style. The motivation is not to implement
-all functions in C<R> by C<perl>, but to help programming in perl vectorized. And
-the module also provide a lot of functions to do basic statistical work.
+The module implements some functions in R style. The motivation is to help perl
+programming vectorized. And the module also provides a lot of functions to do basic statistic work.
 
 =head2 Apply family functions
 
 Apply family functions in R are used to apply functions on categories of data.
 In this module, four apply functions are implemented. It can easily vectorize
-the perl programming where the vectors are represented as array references.
-Unluckily, the code May be a little hard to read.
+perl programming where the vectors are represented as array references.
+However, the code may be a little hard to read.
 
 =over 4
 
 =item C<sapply(ARRAY_REF, CODE_REF)>
 
-To apply a function on every element of the array. Maybe it is more proper to name
-this function as C<apply>. But to be consistent with C<R>, C<apply> function is used
-to apply functino on certain dimension of matrix or array while C<sapply> function
-is used to apply function on every element of the member of a vector. So we name
+To apply a function on every element in the array. Maybe it is more proper to name
+this function as C<apply>. But to be consistent with the function name in R where C<apply> is used
+to apply functions on certain dimension of matrix and C<sapply> function
+is used to apply function on every element of a vector, so we name
 the function as C<sapply> here.
 
   my $a = [1..10];
   my $b = sapply($a, sub {1/$_[0]});
   print_ref $b;
 
-One should note that the functions in to argument return values in a scalar environment.
-So make sure your function only return a scalar.
+The function returns an array reference with same length of the input vector.
+
+Since C<sapply> can reduce the amount of C<for> or C<foreach>, it would sometimes
+make the source code more readable. For example, when we write a blogging software,
+we want to get all post ids, post titles and post times of some author, the code can be 
+written as:
+
+  my $post_id = get_post_id_by_author($author);
+  my $post_title = get_post_title_by_author($author);
+  my $post_createtime = get_post_createtime_by_author($author);
+  
+And C<$post_id>, C<$post_title> and C<$post_createtime> are all array references
+and can be sent to some template softwares such as L<Template>.
 
 =item C<mapply(ARRAY_REF, ARRAY_REF, ..., CODE_REF)>
 
@@ -113,14 +162,16 @@ extension of C<sapply> and it can implement most of the vectorized calculation.
 
   my $x = [1..26];
   my $y = [1..26];
+  # if you think x and y are all vectors, then z is also a vector
   # z = x^2 + 1/y + x*y
   my $z = mapply($x, $y, sub{$_[0]**2 + 1/$_[1] + $_[0]*$_[1]});
-  print_ref $b;
+  print_ref $z;
 
-We will show how to translate algorithms in C<R> code into C<perl>. The following
+We will show how to translate algorithms in R code into perl. The following
 code is to calculate false discovery rate (FDR, BH process) in multiple test problem
 (see source code of C<p.adjust> function).
-
+  
+  # source code of BH part in p.adjust
   lp <- length(p)
   n <- length(p)
   i <- lp:1
@@ -135,21 +186,37 @@ that can calculate cummulative values in the vector. Then the translation looks
   # p-values are stored in @$p
   # lp <- length(p)
   my $lp = len($p);
+  
+  # n <- length(p)
   my $n = $lp;
+  
   # i <- 1p:1
   my $i = seq($lp, 1);
+  
   # o <- order(p, decreasing = TRUE)
   my $o = order($p, sub {$_[1] <=> $_[0]});  # descreasing
+  
   # ro <- order(o)
   my $ro = order($o);
+  
   # n/i * p[o]
   my $foo1 = mapply($i, subset($p, $o), sub {$n/$_[0]*$_[1]})
+  
   # cummin(n/i * p[o])
   my $foo2 = cumf($foo1, \&min);
-  # pmin(1, cummin(n/i * p[o]))
-  my $foo3 = sapply($foo2, sub {$_[0] < 1 ? $_[0] : 1});
+  
+  # pmin(1, cummin(n/i * p[o])), pmin means parallel min
+  my $foo3 = mapply(1, $foo2, sub {min(\@_)});
+  # or just
+  my $foo3 = sapply($foo2, sub{min([$_[0], 1])});
+  
   # ok, the finnal pmin(1, cummin(n/i * p[o]))[ro]
   my $adjp = subset($foo3, $ro);
+  # well, you can also use
+  my $adjp = \@$foo3[@$ro];
+  
+Although the translation is longer than source R code, but it would help to implement
+algorithms from R to perl more conviniently. 
 
 =item C<happly(ARRAY_REF, CODE_REF)>
 
@@ -165,7 +232,8 @@ then it is similar to the C<sapply> function. The function returns a hash refere
 To apply a function on the elements of every catelogy according to the tabulation.
 The first argument is the value array reference, the last argument is the code
 reference, and the others are the array reference for tabulation. The function returns
-a hash reference.
+a hash reference. If the amount of the tabulation array is more than one, the strings
+of different tabulations are seperated by "|".
 
   my $x = [1..10];
   my $t1 = ["a", "a", "a", "a", "a", "b", "b", "b", "b", "b"];
@@ -181,7 +249,7 @@ a hash reference.
   
 =head2 List functions
 
-Functions to manuplate lists. Lists are represented as array references.
+Functions to manuplate lists/vectors. Lists/vectors are represented as array references.
 
 =over 4
 
@@ -189,24 +257,29 @@ Functions to manuplate lists. Lists are represented as array references.
 
 If the argument is an array reference, then it returns the array's length. If it is a hash
 reference, then returns the hash's value's length. If the argument is not defined, then 
-returns 0, or else 1.
-
-The function returns a number.
+returns 0, or else 1. The function returns a number.
 
   print len([1..10]);
   print len({"a" => 1, "b" => 2});
   print len(undef);
   print len(1);
+  print len([]);
+  print len({});
 
-=item C<initial_array(SCALAR (size), SCALAR | CODE_REF (value) )>
+=item C<initial_array(SCALAR (size), SCALAR | CODE_REF | ARRAY_REF | HASH_REF (value) )>
 
 Initialize an array with some values. The first argument is the size of the array
 and the second argument is either a scalar or code reference. If it is a scalar,
 the value of the scalar will be repeated to fill the array. If it is a code refence,
-the value of the array will be generated by the code. By default, the second argument
-is C<undef>. The functions returns an array reference.
+the value of the array will be generated by the code. If it is an array reference or
+hash reference, the value would be copyed instead of just repeat the address of the reference.
+By default, the second argument is C<undef>. The functions returns an array reference.
 
+  my $x = initial_array(10);
+  my $x = initial_array(10, 1);
   my $x = initial_array(10, sub{rand});
+  my $x = initial_array(10, [1, 2]);
+  my $x = initial_array(10, {a => 1, b => 2});
   print_ref $x;
 
 =item C<initial_matrix(SCALAR (n_row), SCALAR (n_col), SCALAR | CODE_REF (value) )>
@@ -215,15 +288,15 @@ Initial a matrix. The arguments are similar to C<initial_array>.
 
 The functions returns a matrix (reference of a two dimensional array reference).
 
-  # a 2x2 matrix initialized with random numbers from uniform distribution in (0, 1)
+  # a 2x2 matrix initialized with random numbers from a uniform distribution in (0, 1)
   my $x = initial_matrix(10, 10, sub{rand});
   print_matrix $x;
 
 =item C<order(ARRAY_REF (value), CODE_REF (sorting function) )>
 
 Returns the order of the elements in the array. The function returns an array reference.
-By default, the sorting function is to sort numbers. Variables C<$a> and C<$b> are replaces
-with C<$_[0]> and C<$_[1]>.
+By default, the sorting function is to sort numbers from smallest to largest. 
+Variables C<$a> and C<$b> are replaces with C<$_[0]> and C<$_[1]>.
 
   my $x = [3, 1, 14, 6, 26];
   my $o = order($x);
@@ -235,9 +308,10 @@ with C<$_[0]> and C<$_[1]>.
   $o = order($x, sub {$_[0] cmp $_[1]);
   print_ref $o;
 
-=item C<rank(ARRAY_REF (value) )>
+=item C<rank(ARRAY_REF (value), CODE_REF (sorting function) )>
 
 Returns the rank of the elements in the array. The function returns an array reference.
+The argument is same as C<order>
 
 =item C<sort_array(ARRAY_REF (value), CODE_REF (sorting function) )>
 
@@ -265,7 +339,7 @@ Same as C<repeat>.
 
 =item C<copy(REF)>
 
-copy a new data from a reference. The new data has the same values as the old data
+Copy a new data from a reference. The new data has the same values as the old data
 but locates at different address.
 
   my $x = {a => [1, 2], b => [3, 4]};
@@ -273,7 +347,7 @@ but locates at different address.
 
 =item C<paste(ARRAY_REF | SCALAR, ARRAY_REF | SCALAR, ..., SCALAR (seperation) )>
 
-Paste strings in arrays. If the last argument is a scalar and not a reference, it is used
+Paste strings in arrays in parallel. If the last argument is a scalar and not a reference, it is used
 as the seperation character. The default seperation character is "|". 
 
   my $x1 = "a";
@@ -286,7 +360,8 @@ as the seperation character. The default seperation character is "|".
 Generate a list of numbers.
 
   my $x = seq(1, 10);
-  $x = seq(1, 10, 2);
+  my $x = seq(1, 10, 3);
+  my $x = seq(10, 1);
 
 =item C<c(ARRAY_REF | SCALAR, ...)>
 
@@ -297,7 +372,7 @@ combine values into an array, only array reference and scalar is permitted.
 =item C<test(ARRAY_REF, CODE_REF)>
 
 Test whether the values meet the condition of the function. The function returns
-an array reference.
+an array reference. The values in the returned array is 0 or 1;
 
   my $x = seq(-5, 5);
   my $l = test($x, sub {$_[0] > 0});
@@ -319,6 +394,7 @@ variable, use C<which> function.
   my $x = seq(-5, 5);
   my $s = subset($x, sub{$_[0] > 0});
   $s = subset($x, [1, 2, 3]);
+  $s = subset($x, [1, 1, 2, 2, 3, 3]);
   $s = subset($x, [-1, -2, -3]);
   $s = subset($x, [1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0]);
   $s = subset($x, which([1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0]));
@@ -327,7 +403,7 @@ variable, use C<which> function.
 
 Change subset values. The first and the second arguments are similar to the C<subset>,
 and the third argument is the value that will replace the value in the origin array. It can
-be either an array reference having the same length as the position having true values or
+be either an array reference having the same length as the values to be replaced or
 a scalar.
 
   my $x = seq(-5, 5);
@@ -336,7 +412,7 @@ a scalar.
   
 =item C<del_array_item(ARRAY_REF, SCALAR | ARRAY_REF)>
 
-Delete items in an array.
+Delete items in an array. The second argument refers to single position or multiple positions.
 
   my $x = [1..10];
   del_array_item($x, 2);
@@ -344,7 +420,7 @@ Delete items in an array.
 
 =item C<which(ARRAY_REF)>
 
-Return the index having true values.
+Return the index of the elements in the array that have true values.
 
   my $x = seq(-5, 5);
   my $l = test($x, sub {$_[0] > 0});
@@ -352,11 +428,11 @@ Return the index having true values.
 
 =item C<all(ARRAY_REF)>
 
-Test whether all items are true
+Test whether all items are true. Return 1 or 0.
 
 =item C<any(ARRAY_REF)>
 
-Test whether at least one of the items is true
+Test whether at least one of the items is true. Return 1 or 0.
 
 =item C<match(ARRAY_REF, ARRAY_REF)>
 
@@ -392,7 +468,7 @@ Product a list of matrixes.
 
 =item C<inner(ARRAY_REF, ARRAY_REF, CODE_REF)>
 
-Inner function on two arrays. The same as the C<mapply> with two arrays. The default function is
+Inner function on two arrays. The same as the sum of C<mapply> with two arrays. The default function is
 production.
 
 =item C<outer(ARRAY_REF, ARRAY_REF, CODE_REF)>
@@ -413,25 +489,26 @@ whether the two arrays are similarly same.
 
 whether the two matrixes are similarly same.
 
-=item C<is_empty(ARRAY_REF)>
+=item C<is_empty(ARRAY_REF | HASH_REF | SCALAR)>
 
-whether the reference is empty.
+whether the reference or value is empty. If the array reference or hash reference
+has length under C<len> is 0 (note the reference itself is logically true), then it returns 0;
 
-=item C<plus(ARRAY_REF, ARRAY_REF, ...)>
+=item C<plus(ARRAY_REF | SCALAR_REF, ARRAY_REF | SCALAR_REF, ...)>
 
 plus of arrays
 
   my $r = plus([1..10], [2..11], 2);
 
-=item C<minus(ARRAY_REF, ARRAY_REF, ...)>
+=item C<minus(ARRAY_REF | SCALAR_REF, ARRAY_REF | SCALAR_REF, ...)>
 
 minus of arrays
 
-=item C<multiply(ARRAY_REF, ARRAY_REF, ...)>
+=item C<multiply(ARRAY_REF | SCALAR_REF, ARRAY_REF | SCALAR_REF, ...)>
 
 multiply of arrays
 
-=item C<divide(ARRAY_REF, ARRAY_REF, ...)>
+=item C<divide(ARRAY_REF | SCALAR_REF, ARRAY_REF | SCALAR_REF, ...)>
 
 divide of arrays
 
@@ -469,7 +546,7 @@ Items exist in the first set while not in the second set.
 
 =item C<setequal(ARRAY_REF, ARRAY_REF)>
 
-whether the two arrays are equal.
+whether the two sets are equal. Sets are arrays that have been unified.
 
 =item C<is_element(SCALAR, ARRAY_REF)>
 
@@ -488,8 +565,11 @@ whether the element is in the set
 
 print the data structure of the reference.
 
-  my $a = [1..10];
-  print_ref $a;
+  print_ref [1..10];
+  print_ref {a => 1, b => 2};
+  print_ref \1;
+  print_ref \\1;
+  print_ref sub {1};
 
 =item C<print_matrix(ARRAY_REF)>
 
@@ -497,17 +577,19 @@ print the content of the matrix.
 
 =item C<read_table(SCALAR, HASH)>
 
-read matrix from file. The first argumetn is the path of the file. The other
+read matrix from file. The first argument is the path of the file. The other
 arguments are as follows.
 
   quote       charector to quote the value (no quoting)
   sep         seperation character (\t)
   col.names   whether take first column as column names
   row.names   whether take first row as row names
-  col.skip    columns being skipped, array ref, start with 1
-  row.skip    rows being skipped, array ref, start with 1
 
-The function return a list with three elements: colnames, rownames, and the data matrix
+The function return a list with three elements: the data matrix, colnames, rownames
+in a list context. While in a scalar context, it only returns the data matrix.
+
+  my ($mat, $cn, $rn) = read_table('some_file_as_table');
+  my $mat = read_table('some_file_as_table');
 
 =item C<write_table(ARRAY_REF, HASH)>
 
@@ -527,14 +609,16 @@ For example
   my $rownames = ["r1", "r2"];
   write_table($x, "file" => "file.txt",
                   "quote" => "\"",
-				  "sep" => "\t",
-				  "col.names" => $colnames,
-				  "row.names" => $rownames,);
+                  "sep" => "\t",
+                  "col.names" => $colnames,
+                  "row.names" => $rownames,);
 
 =back
 
 =head2 Statistical functions
 
+Simple functions but used very frequently.
+
 =over 4
 
 =item C<abs($value)>
@@ -543,15 +627,11 @@ return the absolute value
 
 =item C<sign($value)>
 
-return the sign of a value
+return the sign of a value (1|0|-1)
 
 =item C<sum(ARRAY_REF)>
 
-Summmation of a list of numbers. The numbers should be stored as an array reference.
-
-=item C<prod(ARRAY_REF)>
-
-Production of a list of numbers.
+Summmation of a list of numbers.
 
 =item C<mean(ARRAY_REF)>
 
@@ -561,13 +641,13 @@ Mean value of a list of numbers.
 
 Geometric mean value of a list of numbers.
 
-=item C<sd(ARRAY_REF)>
+=item C<sd(ARRAY_REF, SCALAR)>
 
-Standard deviation of a list of numbers.
+Standard deviation of a list of numbers. The second argument is the mean value (optional)
 
-=item C<var(ARRAY_REF)>
+=item C<var(ARRAY_REF, SCALAR)>
 
-Variance of a list of numbers.
+Variance of a list of numbers. The second argument is the mean value (optional)
 
 =item C<cov(ARRAY_REF, ARRAY_REF)>
 
@@ -575,20 +655,21 @@ Coviarance of two vectors.
 
 =item C<cor(ARRAY_REF, ARRAY_REF, SCALAR)>
 
-Correlation coefficient of two vectors. The third argument is "pearson" or "spearman".
+Correlation coefficient of two vectors. The third argument is "pearson" (by default) or "spearman".
 
 =item C<dist(ARRAY_REF, ARRAY_REF, SCALAR)>
 
-Distance between two vectors. Several definition of the distance is provided.
+Distance between two vectors. Several definition of the distance are provided.
 
-  euclidean  Euclidean distance
+  euclidean  Euclidean distance (by default)
   person     Person correlation coefficient
   spearman   Spearman correlation coefficient
   logical    It is defined as 1/(1+k) where k is the number of items that are both ture in two vectors.
 
 =item C<freq(ARRAY_REF, ARRAY_REF, ...)>
 
-Frequency of the items in an array or arrays. Returns a hash reference.
+Frequency of the items in an array or arrays. Returns a hash reference. Different catelogical strings
+are seperated by "|".
 
   my $a = ["a", "a", "a", "a", "b", "b", "b", "b"];
   my $b = ["1", "2", "1", "2", "1", "2", "1", "2"];
@@ -603,13 +684,19 @@ The same as C<freq>, to be consist with R
 
 Scale the vector based on some criterion.
 
-  zvalue        vector has mean value of 0 and variance of 1
+  zvalue        vector has mean value of 0 and variance of 1 (by default)
+                formula: (x-mean)/sd
   percentage    values in the vector are between 0 - 1
+                formula: (x-min)/(max-min)
   sphere        format the n-dimensional point on the surface of the unit super sphere
+                formula: x/radius
 
 =item C<sample(ARRAY_REF, SCALAR (size), HASH)>
 
-Random samplings and permutations. 
+Random samplings and permutations. The third argument is
+  
+  p         probability for each sampling, values will be scaled into [0, 1]
+  replace   whether sampling with replacement. 1|0
 
   my $x = ["a".."g"];
   # sample without replacement
@@ -624,7 +711,8 @@ Random samplings and permutations.
 
 =item C<rnorm(SCALAR (size), SCALAR (mean), SCALAR (sd))>
 
-Generate random numbers from normal distribution.
+Generate random numbers from normal distribution. Default mean value is 0 and default
+standard deviation is 1.
 
   my $x = rnorm(10);
   $x = rnorm(10, 1, 2);
@@ -657,10 +745,11 @@ only the take the first one.
 
 Median value in a vector.
 
-=item C<quantile(ARRAY_REF, ...)>
+=item C<quantile(ARRAY_REF, ARRAY_REF | SCALAR_REF )>
 
-quantile, the second argument can be a single p-value or a list of p-values storted in an array reference.
-The return value type is same as the second argument.
+quantile, the second argument can be a single percentage or a list of percentages storted in an array reference.
+The return value type is same as the second argument. If the second argumet is not
+specified, it will take [0, 0.25, 0.5, 0.75, 1].
 
   my $x = rnorm(100);
   my $q = quantile($x, 0.5);
@@ -672,8 +761,7 @@ Inter quantile range. It is the distance between the 25th and the 75th quantiles
 
 =item C<cumf(ARRAY_REF, CODE_REF)>
 
-cummulative function on an array. If you want to calculte the empirical cumularive
-distribution. The function take array reference as argument.
+cummulative function on an array. 
 
   my $x = rnorm(10);
   my $sum = sum($x);
@@ -681,6 +769,46 @@ distribution. The function take array reference as argument.
 
 =back
 
+=head1 COMMAND LINE
+
+We provide some scripts to manuplate text files.
+
+=item C<l.intersect file1 file2 ...>
+
+Find same lines in a list of files.
+
+=item C<l.union file1 file2 ...>
+
+Integrate lines in a list of files.
+
+=item C<l.setdiff file1 file2>
+
+Find lines in the first file while not in the second file.
+
+=item C<l.unique file>
+
+Remove repeated lines
+
+=item C<l.sort file [sort_function]>
+
+Sort lines by certain function. Function should looks like C<sub {$a <=> $b}>,
+C<sub {$_[0] cmp $_[1]}> or C<{$a <=> $b}>. That means you can use C<$a>/C<$b> or
+C<$_[0]>/C<$_[1]> to represent two items while sorting.
+
+=item C<l.sapply file [apply_function]>
+
+Apply function on each line in a file. Function should looks like C<sub {$_}>,
+C<sub {$_[0]}> or C<{$_}>. That means you can use C<$_[0]> or C<$_> to represent
+line in the file.
+
+=item C<l.subset file [subset_function]>
+
+Extract line that satidfy some rule in a file. Function should looks like C<sub {$_ E<lt> 0}>,
+C<sub {$_[0] E<lt> 0}> or C<{$_ E<lt> 0}>. That means you can use C<$_[0]> or C<$_> to represent
+line in the file.
+
+=back
+
 =head1 AUTHOR
 
 Zuguang Gu E<lt>jokergoo@gmail.comE<gt>
@@ -694,3 +822,4 @@ it under the same terms as Perl itself, either Perl version 5.12.1 or,
 at your option, any later version of Perl 5 you may have available.
 
 =cut
+
